@@ -78,7 +78,7 @@ def get_devices(api_key):
         return [(r['deviceName'], r['deviceId']) for r in response['records']]
     return False
 
-def send_notification(api_key, text, device_id=None, device_ids=None, device_names=None, title=None, icon=None, smallicon=None, vibration=None, image=None, url=None, tts=None, tts_language=None, sound=None, notification_id=None, actions=None):
+def send_notification(api_key, text, device_id=None, device_ids=None, device_names=None, title=None, icon=None, smallicon=None, vibration=None, image=None, url=None, tts=None, tts_language=None, sound=None, notification_id=None, category=None, actions=None):
     if device_id is None and device_ids is None and device_names is None: return False
     req_url = SEND_URL + api_key + "&text=" + text
     if title: req_url += "&title=" + title
@@ -91,6 +91,7 @@ def send_notification(api_key, text, device_id=None, device_ids=None, device_nam
     if tts_language: req_url += "&language=" + tts_language
     if sound: req_url += "&sound=" + sound
     if notification_id: req_url += "&notificationId=" + notification_id
+    if category: req_url += "&category=" + category
     if device_id: req_url += "&deviceId=" + device_id
     if device_ids: req_url += "&deviceIds=" + device_ids
     if device_names: req_url += "&deviceNames=" + device_names
@@ -148,3 +149,10 @@ def send_sms(api_key, sms_number, sms_text, device_id=None, device_ids=None, dev
     if device_names: req_url += "&deviceNames=" + device_names
     requests.get(req_url)
 
+def set_mediavolume(api_key, mediavolume, device_id=None, device_ids=None, device_names=None):
+    if device_id is None and device_ids is None and device_names is None: return False
+    req_url = SEND_URL + api_key + "&mediaVolume=" + mediavolume
+    if device_id: req_url += "&deviceId=" + device_id
+    if device_ids: req_url += "&deviceIds=" + device_ids
+    if device_names: req_url += "&deviceNames=" + device_names
+    requests.get(req_url)
